********
Coloring
********

.. automodule:: networkx.algorithms.coloring
.. autosummary::
   :toctree: generated/

   greedy_color
   equitable_color

Some node ordering strategies are provided for use with :func:`greedy_color`.

.. autosummary::
   :toctree: generated/

    strategy_connected_sequential
    strategy_connected_sequential_dfs
    strategy_connected_sequential_bfs
    strategy_independent_set
    strategy_largest_first
    strategy_random_sequential
    strategy_saturation_largest_first
    strategy_smallest_last
